<template>
  <div class="mobile-device">
    <div class="search-box">
      <van-dropdown-menu active-color="#1989fa">
        <van-dropdown-item v-model="querys[3].value" :options="statusList" @change="teamChange" />
        <van-dropdown-item v-model="querys[1].value" :options="handleStatusList" @change="teamChange" />
      </van-dropdown-menu>
    </div>

    <van-pull-refresh v-model="refreshing" @refresh="onRefresh" class="van-hairline--top">
      <van-list v-model="loading" :finished="finished" finished-text="没有更多了" @load="onLoad">
        <div v-for="(device, index) in deviceData" :key="index" class="device van-hairline--bottom"
          :class="{ myStyle: index === deviceData.length - 1 }" @click="handleDetail(device)">
          <div class="device-item">
            <div class="device-item-text">
              <div class="device-item-content" style="margin-bottom: 6px">
                <div>
                  <div class="device-name">
                    {{ device.warnName }}
                  </div>
                </div>
                <div class="device-status" :style="device.handleStatus == '待调度'
                    ? { backgroundColor: '#E6A23C' }
                    : device.handleStatus == '处置完成'
                      ? { backgroundColor: '#13ce66' }
                      : device.handleStatus == '待处理'
                        ? { backgroundColor: '#ff4949' }
                        : device.handleStatus == '正在处置'
                          ? { backgroundColor: '#409EFF' }
                          : device.handleStatus == '已归档'
                            ? { backgroundColor: '#191970' }
                            : device.handleStatus == '已评估'
                              ? { backgroundColor: '#8a2be2' }
                              : { backgroundColor: '#a9a9a9' }
                  ">
                  {{ device.handleStatus }}
                </div>
              </div>
            </div>
            <div class="device-content">
              <p>
                <span style="color:#333">告警时间：</span>{{ device.warnTime }}
              </p>
              <p>
                <span style="color:#333">告警缘由：</span>{{ device.warnReason }}
              </p>
              <p>
                <span style="color:#333">处理结果：</span>{{ device.handleResult }}
              </p>
            </div>
          </div>
        </div>
      </van-list>
    </van-pull-refresh>
  </div>
</template>

<script>
import dangerousDevice from '@/api/device/dangerousDevice.js'
import productManage from '@/api/device/productManage.js'
import req from '@/request.js'
import resourceManage from '@/api/device/resourceManage.js'
import equipmentIndex from '@/api/device/equipmentIndex.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'MobileDevice',
  data() {
    return {
      activeIds: [],
      activeChildrenIndex: 0,
      activeIndex: 0,
      policeList: [],
      treeData: [],
      treeChildrenData: [],
      queryParam: {
        pageBean: ''
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'warn.DEVICE_TYPE_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'handleStatus',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'handleStatus',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'warn.DEVICE_TYPE_',
          relation: 'AND',
          value: '1'
        }
      ],
      page: 1,
      startPicker: false,
      statusData: { name: '', value: '' },
      title: '我的设备',
      currentUser: {},
      params: {
        trainingDate: ''
      },
      previewUrl:
        window.context.portal + '/file/onlinePreviewController/v1/getFileById_', //图标预览
      columns: [], //产品列表
      startColumns: [],
      product: {
        name: '',
        id: ''
      },
      statusList: [
        { text: '危险源设备', value: '3' },
        { text: '积水设备', value: '2' },
        { text: '标识牌设备', value: '1' },
        { text: '防暴路障', value: '4' }
      ],
      handleStatusList: [], //处理状态字典
      showPicker: false,
      deviceData: [],
      loading: false,
      finished: true,
      refreshing: false
    }
  },
  created() {
    this.handleStatusList = dictUtils.getDictItemsFromCache('clzt')
    this.handleStatusList = this.handleStatusList.map(item => {
      return { text: item.name, value: item.value }
    })
    this.handleStatusList[0] = {
      text: '请选择',
      value: ''
    }
  },
  mounted() {
    this.currentUser = JSON.parse(sessionStorage.getItem('currentUser'))
    this.deviceStatus = dictUtils.getDictItemsFromCache('sbzt')
    this.onLoad()
    this.getTreen()
  },
  methods: {
    onNavClick(val) {
      console.log(val)
      this.treeChildrenData = this.treeData[val].childrens
      // this.loadData(val.id)
    },
    // 产品组织树查询
    getTreen() {
      productManage.getProductTree().then(res => {
        console.log(res)
        res.value.map(item => {
          item.children = item.children.map(items => {
            items.children = items.children.map(v => {
              return {
                id: v.id,
                text: v.name
              }
            })
            return {
              children: items.children,
              id: items.id,
              text: items.name
            }
          })
        })
        this.treeData = res.value.map(item => {
          return {
            childrens: item.children,
            id: item.id,
            text: item.name
          }
        })
        this.treeChildrenData = this.treeData[0].childrens
        console.log(this.treeData, this.treeChildrenData)
        // this.$set(this.treeData)
      })
    },
    // 跳转设备详情
    handleDetail(item) {
      // this.$router.push({name: 'AlarmData', query: {id: item.id}})
    },
    onCancel() {
      this.showPicker = false
    },
    onLoad() {
      // console.log(9999999)
      // // this.page = -1
      // // this.getDevice()
      setTimeout(() => {
        this.loading = true
        this.getDevice()
      }, 500)
    },
    onRefresh() {
      setTimeout(() => {
        this.page = 1
        this.refreshing = true
        this.deviceData = []
        this.getDevice()
      }, 500)
    },
    teamChange(v) {
      this.page = 1
      this.deviceData = []
      this.getDevice()
    },
    getDevice() {
      this.finished = false
      this.queryParam.pageBean = { pageSize: 10, page: this.page }
      // this.loading = true
      this.queryParam.sorter = [
        {
          direction: 'DESC',
          property: 'warnTime'
        }
      ]
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      dangerousDevice.loadInfo(this.queryParam, res => {
        console.log(res, 'res')
        this.loading = false
        res.rows.forEach(item => {
          this.handleStatusList.forEach(val => {
            if (item.handleStatus == val.value) {
              item['handleStatus'] = val.text
            }
          })
        })
        this.deviceData = this.deviceData.concat(res.rows)
        console.log(this.deviceData)
        this.page++
        // 如果加载完毕，显示没有更多了
        if (res.rows.length === 0) {
          this.finished = true
        }
        setTimeout(() => {
          //code
          this.refreshing = false
        }, 1000)
      })
    }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

.van-cell__title span,
.van-cell__value span {
  font-size: 82px;
}

.van-cell__value span {
  color: $--mobile-text-active;
}

::v-deep .device .device-item-text[data-v-1449fbde] {
  border-bottom: 0;
}

.search-box {
  width: 100%;
  z-index: 10;
  // padding-top: 200px;
}

.treeDataLeft {

  //修改左侧宽度
  .van-tree-select__nav {
    flex: 1 !important;
  }

  .van-tree-select__content {
    flex: 1.6 !important;
  }
}

.device {
  background: #fff;
  background-color: #f5f5f5;
  // margin-bottom: 6px;
  padding: 40px 40px 0 40px;
  box-sizing: border-box;
  color: $--mobile-text-sub;
  // display: flex;
  // align-items: center;
  width: 100%;

  .device-item {
    background-color: #fff;
    border-radius: 60px;
    padding: 20px 100px 20px 100px;
  }

  .device-content {
    // padding: 50px 0px 50px 0px;
    font-size: 50px;

    p {
      margin: 10px 0 10px 0;
    }
  }

  .device-item-img {
    width: 256px;
    height: 256px;

    img {
      width: 100%;
      height: 100%;
    }
  }

  .device-item-text {
    padding: 20px 0px 20px 0px;
    // margin-left: 10px;
    // width: calc(100% - 256px - 10px);
    border-bottom: 1px solid #dedddd;
  }

  .device-item-content {
    display: flex;
    justify-content: space-between;
    align-items: center;

    span {
      font-size: 72px;
    }
  }

  .device-name {
    width: 90%;
    font-family: ”Microsoft YaHei”, Arial, Helvetica, sans-serif, ”宋体”;
    font-size: 68px;
    color: $--mobile-text-main;
  }

  .device-name-icon {
    color: $-mobile-primary;
    margin-right: 2px;
  }

  .device-code {
    color: $--mobile-text-sub;
    font-size: 82px;
  }

  .device-item-title {
    color: #49a1f9;
    margin-right: 2px;
  }

  .device-status {
    // width: 300px;
    // text-align: center;
    // color: white;
    width: 230px;
    border-radius: 5px;
    padding: 5px 20px;
    font-size: 50px;
    text-align: center;
    color: white;
  }

  // .device-status.van-tag {
  //   padding: 4px 6px;
  // }
  .van-tag {
    width: 200px;
    display: flex;
    justify-content: center;
  }
}

.myStyle {
  padding: 40px 40px 40px 40px;
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom.scss';
</style>
